import { Component, OnInit } from '@angular/core';
import { ApiService } from './service/api.service';
import { NzMessageService } from 'ng-zorro-antd/message';
import { NzModalService } from 'ng-zorro-antd/modal';
import { FormControl, FormGroup, NonNullableFormBuilder, Validators } from '@angular/forms';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent implements OnInit{

  isCollapsed = false;
  folders: any = [];
  images: any = [];
  image : any;
  setting : any;
  buttonDisabled = false ;
  currentFolder: any;
  isVisible = false;
  user : any ;

  validateForm: FormGroup<{
    userName: FormControl<string>;
    password: FormControl<string>;
  }> = this.fb.group({
    userName: ['', [Validators.required, Validators.email]],
    password: ['', [Validators.required]],
  });

  ngOnInit(): void {
    if(localStorage.getItem("user")){
      this.getFolder();
      this.user = JSON.parse(localStorage.getItem("user")!);
    }else{
      this.showModal();
    }
      
  }

  constructor(private apiService: ApiService, private message: NzMessageService,
    private modalService: NzModalService, private fb: NonNullableFormBuilder){

  }


  title = 'imagecompressed';


  createBasicMessage(message : string, type : string): void {
    this.message.create(type, message , {
      nzDuration: 2000
    });
  }


  getFolder(){
    this.apiService.getFolders().subscribe((data: any) => {
      this.folders = data;
     // console.log(this.folders);
    })
  }

  getFolderImage(folder:any){
    this.currentFolder = folder;
    this.buttonDisabled = false;
    this.apiService.getFiles(folder.name).subscribe((data: any) => {
      this.images = data;
      this.getSetting();
     // console.log(this.images)
    })
  }

  getSetting(){
    this.apiService.getFileSetting(this.currentFolder.name).subscribe((data : any) => {
      this.setting = data ;
      if(this.currentFolder){
        this.stateButton();
      }
    })
  }

  stateButton(){
    for(const [key, value] of Object.entries(this.setting)){
        if(key == this.user.identifiant){
          if(this.setting[key].state == "1"|| this.setting[key].state == "0" || this.setting[key].state == "-1"){
              this.buttonDisabled=true;
            //  console.log(this.setting.state)
              this.createBasicMessage("Vous avez vérifié ce dossier avec un statut "+ this.setting[key].state, "info")
          }
        }
    }

  
  }

  addFileSetting(state : string){
    if(this.currentFolder){
      this.apiService.addFileSetting(this.currentFolder.name, state, this.user.identifiant).subscribe((data : any ) => {
        this.getSetting()
     })
    }else{
      this.createBasicMessage("Veuillez choisir un dossier d'image", "info")
    }

  }

  submitForm(): void {
    if (this.validateForm.valid) {
    //  console.log('submit', this.validateForm.value);

      let data = {
        email : this.validateForm.value.userName,
        password : this.validateForm.value.password
      }
      this.apiService.loginOrAdd(data).subscribe((user_response : any) => {
        this.user = user_response;
        if(this.user.identifiant){
       //   console.log(this.user)
          this.isVisible = false;
          this.createBasicMessage("Authentification réussie", "info");
          localStorage.setItem("user", JSON.stringify(user_response));
          this.getFolder()
        }else{
          this.createBasicMessage("Veuillez remplir le bon mot de passe", "error")
        }
      })
    } else {
      this.createBasicMessage("Identifiants invalides", "error")
      Object.values(this.validateForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  showModal(): void {
    this.isVisible = true;
  }

  handleOk(): void {
    this.isVisible = false;
  }

  handleCancel(): void {
    this.isVisible = true;
  }

  showConfirm(): void {
    this.modalService.confirm({
      nzTitle: 'Confirm',
      nzContent: 'Bla bla ...',
      nzOkText: 'OK',
      nzCancelText: 'Cancel'
    });
  }
  

}
